import usb.core
import usb.util

# VID i PID twojego urządzenia
VID = 0x0B49  # Twój VID
PID = 0x064F  # Twój PID

# Znalezienie urządzenia
dev = usb.core.find(idVendor=VID, idProduct=PID)

if dev is None:
    raise ValueError("Nie znaleziono urządzenia USB!")

# Ustawienie konfiguracji urządzenia
dev.set_configuration()

# Przygotowanie danych do wysłania (zgodnie z żądaniem 21 09 00 02 00 00 0A 00)
bmRequestType = 0x21  # Host-to-device, class request, interface recipient
bRequest = 0x09       # Request 0x09 (SET_REPORT in HID class)
wValue = 0x0200       # Wartość wValue (0x0200, w HID class to Report Type + Report ID)
wIndex = 0x0000       # Wartość wIndex (interface 0)
wLength = 0x0A        # Długość danych (10 bajtów)

# Przygotowanie danych do wysłania (w tym przypadku możemy użyć pustych danych o długości 10 bajtów)
data_to_send = [0x00] * wLength

# Wysyłanie danych za pomocą kontrolnego transferu USB (setup transfer)
try:
    dev.ctrl_transfer(bmRequestType, bRequest, wValue, wIndex, data_to_send)
    print(f"Wysłano dane z setup: bmRequestType={bmRequestType}, bRequest={bRequest}, wValue={hex(wValue)}, wIndex={hex(wIndex)}, data={data_to_send}")
except Exception as e:
    print(f"Błąd podczas wysyłania danych: {e}")
